@@ -23,6 +23,8 @@
 #include <gio/gio.h>
 #include <libexif/exif-data.h>
 
+#include <math.h>
+
 #include "image_viewer.h"
 #include "settings.h"
 #include "marshal.h"
@@ -1384,7 +1386,11 @@ cb_rstto_image_loader_area_prepared (GdkPixbufLoader *loader, RsttoImageViewerTr
 }
 
 static void
-cb_rstto_image_loader_size_prepared (GdkPixbufLoader *loader, gint width, gint height, RsttoImageViewerTransaction *transaction)
+cb_rstto_image_loader_size_prepared (
+        GdkPixbufLoader *loader,
+        gint width,
+        gint height,
+        RsttoImageViewerTransaction *transaction)
 {
     gint s_width = gdk_screen_get_width (default_screen);
     gint s_height = gdk_screen_get_height (default_screen);
@@ -1406,12 +1412,18 @@ cb_rstto_image_loader_size_prepared (GdkPixbufLoader *loader, gint width, gint h
         if(((gdouble)width / (gdouble)s_width) < ((gdouble)height / (gdouble)s_height))
         {
             transaction->image_scale = (gdouble)s_width / (gdouble)width;
-            gdk_pixbuf_loader_set_size (loader, s_width, (gint)((gdouble)height/(gdouble)width*(gdouble)s_width)); 
+            gdk_pixbuf_loader_set_size (
+                    loader,
+                    s_width,
+                    (gint)((gdouble)height/(gdouble)width*(gdouble)s_width)); 
         }
         else
         {
             transaction->image_scale = (gdouble)s_height / (gdouble)height;
-            gdk_pixbuf_loader_set_size (loader, (gint)((gdouble)width/(gdouble)height*(gdouble)s_width), s_height); 
+            gdk_pixbuf_loader_set_size (
+                    loader,
+                    (gint)((gdouble)width/(gdouble)height*(gdouble)s_height),
+                    s_height); 
         }
     }
     else
@@ -1611,32 +1623,46 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
         {
             case RSTTO_IMAGE_VIEWER_ORIENT_NONE:
                 if ((gtk_adjustment_get_page_size (vadjustment) + 
-                        gtk_adjustment_get_value(vadjustment)) > (viewer->priv->image_height*viewer->priv->scale))
+                        gtk_adjustment_get_value(vadjustment)) > floor(viewer->priv->image_height*viewer->priv->scale))
                 {
                     gtk_adjustment_set_value (vadjustment,
                             (height*relative_scale) -
                             gtk_adjustment_get_page_size (vadjustment));
                 }
                 if ((gtk_adjustment_get_page_size (hadjustment) + 
-                        gtk_adjustment_get_value(hadjustment)) > (viewer->priv->image_width*viewer->priv->scale))
+                        gtk_adjustment_get_value(hadjustment)) > floor(viewer->priv->image_width*viewer->priv->scale))
                 {
                     gtk_adjustment_set_value (hadjustment,
                             (width*relative_scale) - 
                             gtk_adjustment_get_page_size (hadjustment));
                 }
-                gtk_adjustment_set_upper (hadjustment, (gdouble)width*(viewer->priv->scale/viewer->priv->image_scale));
-                gtk_adjustment_set_upper (vadjustment, (gdouble)height*(viewer->priv->scale/viewer->priv->image_scale));
+                gtk_adjustment_set_upper (hadjustment, floor((gdouble)width*(viewer->priv->scale/viewer->priv->image_scale)));
+                gtk_adjustment_set_upper (vadjustment, floor((gdouble)height*(viewer->priv->scale/viewer->priv->image_scale)));
 
-                subpixbuf_x_offset = (gint)(gtk_adjustment_get_value (hadjustment) / relative_scale);
-                subpixbuf_y_offset = (gint)(gtk_adjustment_get_value (vadjustment) / relative_scale);
+                subpixbuf_x_offset = (gint)floor(gtk_adjustment_get_value (hadjustment) / relative_scale);
+                subpixbuf_y_offset = (gint)floor(gtk_adjustment_get_value (vadjustment) / relative_scale);
                 subpixbuf_width = (gint)((gtk_adjustment_get_page_size (hadjustment) / relative_scale) < width)?
-                               (gtk_adjustment_get_page_size (hadjustment) / relative_scale)+1:(width);
+                               ceil(gtk_adjustment_get_page_size (hadjustment) / relative_scale):(width);
                 subpixbuf_height = (gint)((gtk_adjustment_get_page_size (vadjustment) / relative_scale) < height)?
-                               (gtk_adjustment_get_page_size (vadjustment) / relative_scale)+1:(height);
+                               ceil(gtk_adjustment_get_page_size (vadjustment) / relative_scale):(height);
                 break;
             case RSTTO_IMAGE_VIEWER_ORIENT_180:
-                gtk_adjustment_set_upper (hadjustment, (gdouble)width*(viewer->priv->scale/viewer->priv->image_scale));
-                gtk_adjustment_set_upper (vadjustment, (gdouble)height*(viewer->priv->scale/viewer->priv->image_scale));
+                if ((gtk_adjustment_get_page_size (vadjustment) + 
+                        gtk_adjustment_get_value(vadjustment)) > floor(viewer->priv->image_height*viewer->priv->scale))
+                {
+                    gtk_adjustment_set_value (vadjustment,
+                            (height*relative_scale) -
+                            gtk_adjustment_get_page_size (vadjustment));
+                }
+                if ((gtk_adjustment_get_page_size (hadjustment) + 
+                        gtk_adjustment_get_value(hadjustment)) > floor(viewer->priv->image_width*viewer->priv->scale))
+                {
+                    gtk_adjustment_set_value (hadjustment,
+                            (width*relative_scale) - 
+                            gtk_adjustment_get_page_size (hadjustment));
+                }
+                gtk_adjustment_set_upper (hadjustment, floor((gdouble)width*(viewer->priv->scale/viewer->priv->image_scale)));
+                gtk_adjustment_set_upper (vadjustment, floor((gdouble)height*(viewer->priv->scale/viewer->priv->image_scale)));
                 subpixbuf_x_offset = (gint)((gtk_adjustment_get_upper(hadjustment) - 
                                              gtk_adjustment_get_page_size(hadjustment) - 
                                              gtk_adjustment_get_value (hadjustment)) / relative_scale);
@@ -1644,23 +1670,23 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
                                              gtk_adjustment_get_page_size(vadjustment) - 
                                              gtk_adjustment_get_value (vadjustment)) / relative_scale);
                 subpixbuf_width = (gint)((gtk_adjustment_get_page_size (hadjustment) / relative_scale) < width)?
-                               (gtk_adjustment_get_page_size (hadjustment) / relative_scale)+1:(width);
+                               ceil(gtk_adjustment_get_page_size (hadjustment) / relative_scale):(width);
                 subpixbuf_height = (gint)((gtk_adjustment_get_page_size (vadjustment) / relative_scale) < height)?
-                               (gtk_adjustment_get_page_size (vadjustment) / relative_scale)+1:(height);
+                               ceil(gtk_adjustment_get_page_size (vadjustment) / relative_scale):(height);
                 break;
             case RSTTO_IMAGE_VIEWER_ORIENT_270:
-                gtk_adjustment_set_upper (hadjustment, (gdouble)width*(viewer->priv->scale/viewer->priv->image_scale));
-                gtk_adjustment_set_upper (vadjustment, (gdouble)height*(viewer->priv->scale/viewer->priv->image_scale));
+                gtk_adjustment_set_upper (hadjustment, floor((gdouble)width*(viewer->priv->scale/viewer->priv->image_scale)));
+                gtk_adjustment_set_upper (vadjustment, floor((gdouble)height*(viewer->priv->scale/viewer->priv->image_scale)));
 
                 if ((gtk_adjustment_get_page_size (hadjustment) + 
-                        gtk_adjustment_get_value(hadjustment)) > (viewer->priv->image_width*viewer->priv->scale))
+                        gtk_adjustment_get_value(hadjustment)) > floor(viewer->priv->image_width*viewer->priv->scale))
                 {
                     gtk_adjustment_set_value (hadjustment,
                             (width*relative_scale) -
                             gtk_adjustment_get_page_size (vadjustment));
                 }
                 if ((gtk_adjustment_get_page_size (vadjustment) + 
-                        gtk_adjustment_get_value(vadjustment)) > (viewer->priv->image_height*viewer->priv->scale))
+                        gtk_adjustment_get_value(vadjustment)) > floor(viewer->priv->image_height*viewer->priv->scale))
                 {
                     gtk_adjustment_set_value (vadjustment,
                             (height*relative_scale) - 
@@ -1672,23 +1698,23 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
                                              gtk_adjustment_get_value (hadjustment))) / relative_scale);
                 subpixbuf_y_offset = (gint)(gtk_adjustment_get_value (vadjustment) / relative_scale);
                 subpixbuf_width = (gint)((gtk_adjustment_get_page_size (hadjustment) / relative_scale) < width)?
-                               (gtk_adjustment_get_page_size (hadjustment) / relative_scale)+1:(width);
+                               ceil(gtk_adjustment_get_page_size (hadjustment) / relative_scale):(width);
                 subpixbuf_height = (gint)((gtk_adjustment_get_page_size (vadjustment) / relative_scale) < height)?
-                               (gtk_adjustment_get_page_size (vadjustment) / relative_scale)+1:(height);
+                               ceil(gtk_adjustment_get_page_size (vadjustment) / relative_scale):(height);
                 break;
             case RSTTO_IMAGE_VIEWER_ORIENT_90:
-                gtk_adjustment_set_upper (hadjustment, (gdouble)width*(viewer->priv->scale/viewer->priv->image_scale));
-                gtk_adjustment_set_upper (vadjustment, (gdouble)height*(viewer->priv->scale/viewer->priv->image_scale));
+                gtk_adjustment_set_upper (hadjustment, floor((gdouble)width*(viewer->priv->scale/viewer->priv->image_scale)));
+                gtk_adjustment_set_upper (vadjustment, floor((gdouble)height*(viewer->priv->scale/viewer->priv->image_scale)));
 
                 if ((gtk_adjustment_get_page_size (hadjustment) + 
-                        gtk_adjustment_get_value(hadjustment)) > (viewer->priv->image_width*viewer->priv->scale))
+                        gtk_adjustment_get_value(hadjustment)) > floor(viewer->priv->image_width*viewer->priv->scale))
                 {
                     gtk_adjustment_set_value (hadjustment,
                             (width*relative_scale) -
                             gtk_adjustment_get_page_size (vadjustment));
                 }
                 if ((gtk_adjustment_get_page_size (vadjustment) + 
-                        gtk_adjustment_get_value(vadjustment)) > (viewer->priv->image_height*viewer->priv->scale))
+                        gtk_adjustment_get_value(vadjustment)) > floor(viewer->priv->image_height*viewer->priv->scale))
                 {
                     gtk_adjustment_set_value (vadjustment,
                             (height*relative_scale) - 
@@ -1700,9 +1726,9 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
                                              (gtk_adjustment_get_page_size(vadjustment) + 
                                              gtk_adjustment_get_value (vadjustment))) / relative_scale);
                 subpixbuf_width = (gint)((gtk_adjustment_get_page_size (hadjustment) / relative_scale) < width)?
-                               (gtk_adjustment_get_page_size (hadjustment) / relative_scale)+1:(width);
+                               ceil(gtk_adjustment_get_page_size (hadjustment) / relative_scale):(width);
                 subpixbuf_height = (gint)((gtk_adjustment_get_page_size (vadjustment) / relative_scale) < height)?
-                               (gtk_adjustment_get_page_size (vadjustment) / relative_scale)+1:(height);
+                               ceil(gtk_adjustment_get_page_size (vadjustment) / relative_scale):(height);
                 break;
         }
 
@@ -1741,32 +1767,43 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
                     subpixbuf_y_offset,
                     subpixbuf_width,
                     subpixbuf_height);
-
-            switch (viewer->priv->orientation)
+            if (NULL != tmp_pixbuf)
             {
-                case RSTTO_IMAGE_VIEWER_ORIENT_180:
-                    tmp_pixbuf2 = gdk_pixbuf_rotate_simple (tmp_pixbuf, GDK_PIXBUF_ROTATE_UPSIDEDOWN);
-                    g_object_unref (tmp_pixbuf);
-                    tmp_pixbuf = tmp_pixbuf2;
-                    break;
-                case RSTTO_IMAGE_VIEWER_ORIENT_270:
-                    tmp_pixbuf2 = gdk_pixbuf_rotate_simple (tmp_pixbuf, GDK_PIXBUF_ROTATE_COUNTERCLOCKWISE);
-                    g_object_unref (tmp_pixbuf);
-                    tmp_pixbuf = tmp_pixbuf2;
-                    break;
-                case RSTTO_IMAGE_VIEWER_ORIENT_90:
-                    tmp_pixbuf2 = gdk_pixbuf_rotate_simple (tmp_pixbuf, GDK_PIXBUF_ROTATE_CLOCKWISE);
-                    g_object_unref (tmp_pixbuf);
-                    tmp_pixbuf = tmp_pixbuf2;
-                    break;
+
+                switch (viewer->priv->orientation)
+                {
+                    case RSTTO_IMAGE_VIEWER_ORIENT_180:
+                        tmp_pixbuf2 = gdk_pixbuf_rotate_simple (tmp_pixbuf, GDK_PIXBUF_ROTATE_UPSIDEDOWN);
+                        g_object_unref (tmp_pixbuf);
+                        tmp_pixbuf = tmp_pixbuf2;
+                        break;
+                    case RSTTO_IMAGE_VIEWER_ORIENT_270:
+                        tmp_pixbuf2 = gdk_pixbuf_rotate_simple (tmp_pixbuf, GDK_PIXBUF_ROTATE_COUNTERCLOCKWISE);
+                        g_object_unref (tmp_pixbuf);
+                        tmp_pixbuf = tmp_pixbuf2;
+                        break;
+                    case RSTTO_IMAGE_VIEWER_ORIENT_90:
+                        tmp_pixbuf2 = gdk_pixbuf_rotate_simple (tmp_pixbuf, GDK_PIXBUF_ROTATE_CLOCKWISE);
+                        g_object_unref (tmp_pixbuf);
+                        tmp_pixbuf = tmp_pixbuf2;
+                        break;
+                }
+
+                viewer->priv->dst_pixbuf = gdk_pixbuf_scale_simple (tmp_pixbuf,
+                                           (gint)(gdk_pixbuf_get_width(tmp_pixbuf) * relative_scale),
+                                           (gint)(gdk_pixbuf_get_height(tmp_pixbuf) * relative_scale),
+                                           GDK_INTERP_BILINEAR);
+
+                g_object_unref (tmp_pixbuf);
+            }
+            else
+            {
+                g_warning ("TMP Pixbuf could not be created, [x:%d,y:%d,w:%d,h:%d]",
+                        subpixbuf_x_offset,
+                        subpixbuf_y_offset,
+                        subpixbuf_width,
+                        subpixbuf_height);
             }
-
-            viewer->priv->dst_pixbuf = gdk_pixbuf_scale_simple (tmp_pixbuf,
-                                       (gint)(gdk_pixbuf_get_width(tmp_pixbuf) * relative_scale),
-                                       (gint)(gdk_pixbuf_get_height(tmp_pixbuf) * relative_scale),
-                                       GDK_INTERP_BILINEAR);
-
-            g_object_unref (tmp_pixbuf);
         }
 
         /* 
@@ -1798,6 +1835,8 @@ cb_rstto_image_viewer_queued_repaint (RsttoImageViewer *viewer)
 
 
     rstto_image_viewer_paint (GTK_WIDGET (viewer));
+
+    return FALSE;
 }
 
 static gboolean
@@ -2281,7 +2320,7 @@ static gboolean
 rstto_popup_menu (
         GtkWidget *widget)
 {
-    RsttoImageViewer *viewer = RSTTO_IMAGE_VIEWER (viewer);
+    RsttoImageViewer *viewer = RSTTO_IMAGE_VIEWER (widget);
 
     if (viewer->priv->menu)
     {
